Aapt2Optimize

Struct Aapt2Optimize 

pub struct Aapt2Optimize { /* private fields */ }
Preforms resource optimizations on an APK

Implementations

Source

impl Aapt2Optimize

pub fn new(output_apk: &Path, output_dir: &Path) -> Self

Initialize aapt2 optimize then specifies path to the aapt2 link output APK and Path to the output directory (for splits)

pub fn config_xml_file(&mut self, config_xml_file: &Path) -> &mut Self

Specifies path to XML configuration file

pub fn apk_artifacts(&mut self, apk_artifacts: bool) -> &mut Self

Print the multi APK artifacts and exit

pub fn target_densities(&mut self, target_densities: &str) -> &mut Self

Comma separated list of the screen densities that the APK will be optimized for. All the resources that would be unused on devices of the given densities will be removed from the APK

pub fn resources_config_path( &mut self, resources_config_path: &Path, ) -> &mut Self

Path to the resources.cfg file containing the list of resources and directives to each resource. Format: type/resource_name#[directive][,directive]

pub fn configs_to_include(&mut self, configs_to_include: &str) -> &mut Self

Comma separated list of configurations to include. The default is all configurations

pub fn split(&mut self, split: &Path) -> &mut Self

Split resources matching a set of configs out to a Split APK. Syntax:

`path/to/output.apk;<config>[,<config>[...]].`

On Windows, use a semicolon ; separator instead

pub fn keep_artifacts(&mut self, keep_artifacts: &str) -> &mut Self

Comma separated list of artifacts to keep. If none are specified, all artifacts will be kept

pub fn enable_sparse_encoding( &mut self, enable_sparse_encoding: bool, ) -> &mut Self

Enables encoding sparse entries using a binary search tree. This decreases APK size at the cost of resource retrieval performance

pub fn collapse_resource_name( &mut self, collapse_resource_name: bool, ) -> &mut Self

Collapses resource names to a single value in the key string pool. Resources can be exempted using the no_collapse directive in a file specified by --resources-config-path

pub fn shorten_resource_paths( &mut self, shorten_resource_paths: bool, ) -> &mut Self

Shortens the paths of resources inside the APK

pub fn resource_path_shortening_map( &mut self, resource_path_shortening_map: &Path, ) -> &mut Self

Path to output the map of old resource paths to shortened paths

pub fn verbose(&mut self, verbose: bool) -> &mut Self

Enables verbose logging

pub fn help(&mut self, help: bool) -> &mut Self

Displays this help menu

pub fn run(self) -> Result<()>

Executes aapt2 optimize with arguments