pub struct AdbPush { /* private fields */ }Implementations
Sourceimpl AdbPush
impl AdbPush
pub fn new() -> Self
Sourcepub fn sync(&mut self, sync: &Path) -> &mut Self
pub fn sync(&mut self, sync: &Path) -> &mut Self
Only push files that are newer on the host than the device
Sourcepub fn n(&mut self, n: bool) -> &mut Self
pub fn n(&mut self, n: bool) -> &mut Self
Dry run: push files to device without storing to the filesystem
Sourcepub fn z_enable_compression(&mut self, z_enable_compression: bool) -> &mut Self
pub fn z_enable_compression(&mut self, z_enable_compression: bool) -> &mut Self
Enable compression with a specified algorithm (any, none, brotli)
Sourcepub fn z_disable_compression(
&mut self,
z_disable_compression: bool,
) -> &mut Self
pub fn z_disable_compression( &mut self, z_disable_compression: bool, ) -> &mut Self
Disable compression
pub fn run(&self) -> Result<()>